@@ -99,6 +99,8 @@ from neutron_lib.api.definitions import qos
 from neutron_lib.api.definitions import qos_bw_limit_direction
 from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
+from neutron_lib.api.definitions import qos_fip
+from neutron_lib.api.definitions import qos_fip_network_policy
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
 from neutron_lib.api.definitions import qos_pps_minimum_rule
@@ -237,6 +239,8 @@ _ALL_API_DEFINITIONS = {
     qos_bw_limit_direction,
     qos_bw_minimum_ingress,
     qos_default,
+    qos_fip,
+    qos_fip_network_policy,
     qos_gateway_ip,
     qos_port_network_policy,
     qos_pps_minimum_rule,
